@@ -105,6 +105,30 @@ class DescribeVirtualEdgeDatacentersResponse(AbstractModel):
                 self.dcSet.append(obj)
 
 
+class DescribeBorderGatewayDatacentersRequest(AbstractModel):
+    def __init__(self):
+        self.dcId = None
+        self.regionId = None
+
+    def _deserialize(self, params):
+        self.dcId = params.get("dcId")
+        self.regionId = params.get("regionId")
+
+
+class DescribeBorderGatewayDatacentersResponse(AbstractModel):
+    def __init__(self):
+        self.requestId = None  # 请求ID
+        self.dcSet = None  # 虚拟边缘数据中心集合
+
+    def _deserialize(self, params):
+        self.requestId = params.get("requestId")
+        if params.get("dcSet") is not None:
+            self.dcSet = []
+            for item in params.get("dcSet"):
+                obj = DatacenterInfo(item)  # 复用已有的DatacenterInfo结构
+                self.dcSet.append(obj)
+
+
 class QueryDataCenterPortPriceRequest(AbstractModel):
     def __init__(self):
         self.dcId = None
@@ -347,6 +371,7 @@ class CreatePortRequest(AbstractModel):
         self.portRemarks = None
         self.portType = None
         self.businessEntityName = None
+        self.marketingOptions = None
 
     def _deserialize(self, params):
         self.dcId = params.get("dcId")
@@ -354,6 +379,8 @@ class CreatePortRequest(AbstractModel):
         self.portRemarks = params.get("portRemarks")
         self.portType = params.get("portType")
         self.businessEntityName = params.get("businessEntityName")
+        if params.get("marketingOptions") is not None:
+            self.marketingOptions = MarketingInfo(params.get("marketingOptions"))
 
 
 class CreatePortResponse(AbstractModel):
@@ -367,6 +394,24 @@ class CreatePortResponse(AbstractModel):
         self.portId = params.get("portId")
 
 
+
+class MarketingInfo(AbstractModel):
+
+    def __init__(self, params=None):
+        if params is None:
+            params = {}
+        if len(params) > 0:
+            self._deserialize(params)
+            return
+        self.discountCode = None
+        self.usePocVoucher = None
+
+    def _deserialize(self, params):
+        self.discountCode = params.get("discountCode")
+        self.usePocVoucher = params.get("usePocVoucher")
+
+
+
 class DescribeDataCenterPortPriceRequest(AbstractModel):
     def __init__(self):
         self.dcId = None
@@ -767,6 +812,7 @@ class DatacenterInfo(AbstractModel):
         self.longitude = None
         self.isPortAvailable = None
         self.availableBandwidth = None
+        self.regionId = None
 
     def _deserialize(self, params):
         self.dcId = params.get("dcId")
@@ -779,6 +825,7 @@ class DatacenterInfo(AbstractModel):
         self.longitude = params.get("longitude")
         self.isPortAvailable = params.get("isPortAvailable")
         self.availableBandwidth = params.get("availableBandwidth")
+        self.regionId = params.get("regionId")
 
 
 class DescribeCreatePrivateConnectAvailableSubnetsRequest(AbstractModel):
@@ -870,6 +917,7 @@ class CreatePrivateConnectRequest(AbstractModel):
         self.endpointZ = None
         self.bandwidthMbps = None
         self.resourceGroupId = None
+        self.marketingOptions = None
 
     def _deserialize(self, params):
         self.privateConnectName = params.get("privateConnectName")
@@ -879,6 +927,8 @@ class CreatePrivateConnectRequest(AbstractModel):
             self.endpointZ = CreateEndpointParam(params.get("endpointZ"))
         self.bandwidthMbps = params.get("bandwidthMbps")
         self.resourceGroupId = params.get("resourceGroupId")
+        if params.get("marketingOptions") is not None:
+            self.marketingOptions = MarketingInfo(params.get("marketingOptions"))
 
 
 class CreatePrivateConnectResponse(AbstractModel):
@@ -1383,6 +1433,7 @@ class CreateCloudRouterRequest(AbstractModel):
         self.cloudRouterDescription = None
         self.edgePoints = None
         self.resourceGroupId = None
+        self.marketingOptions = None
 
     def _deserialize(self, params):
         self.cloudRouterName = params.get("cloudRouterName")
@@ -1393,6 +1444,8 @@ class CreateCloudRouterRequest(AbstractModel):
                 obj = CreateCloudRouterEdgePoint(item)
                 self.edgePoints.append(obj)
         self.resourceGroupId = params.get("resourceGroupId")
+        if params.get("marketingOptions") is not None:
+            self.marketingOptions = MarketingInfo(params.get("marketingOptions"))
 
 
 class CreateCloudRouterResponse(AbstractModel):
